@@ -389,9 +389,7 @@ class Fibonacci_heap(object):
         # Otherwise, if it's not None, then we write the elements next to the
         # min element around the min element to remove it, then arbitrarily
         # reassign the min.
-        #
-        # DRS: Added this pair of id's Sep 5, 2014
-        if id(self.m_min.m_next) == id(self.m_min):
+        if self.m_min.m_next is self.m_min:
             # Case one
             self.m_min = None
         else:
@@ -413,7 +411,7 @@ class Fibonacci_heap(object):
                 # Walk to the next node, then stop if this is the node we
                 # started at.
                 curr = curr.m_next
-                if id(curr) == id(min_elem.m_child):
+                if curr is min_elem.m_child:
                     # This was a do-while (curr != minElem.mChild);
                     break
 
@@ -446,7 +444,7 @@ class Fibonacci_heap(object):
 
         #for (Entry<T> curr = self.m_min; toVisit.isEmpty() || toVisit.get(0) != curr; curr = curr.m_next)
         curr = self.m_min
-        while not to_visit or id(to_visit[0]) != id(curr):
+        while not to_visit or to_visit[0] is not curr:
             to_visit.append(curr)
             curr = curr.m_next
 
@@ -604,8 +602,7 @@ class Fibonacci_heap(object):
             return
 
         # Rewire the node's siblings around it, if it has any siblings.
-        # DRS added these two id()'s Oct 26, 2014
-        if id(entry.m_next) != id(entry):
+        if entry.m_next is not entry:
             # Has siblings
             entry.m_next.m_prev = entry.m_prev
             entry.m_prev.m_next = entry.m_next
@@ -613,9 +610,8 @@ class Fibonacci_heap(object):
         # If the node is the one identified by its parent as its child,
         # we need to rewrite that pointer to point to some arbitrary other
         # child.
-        # DRS added these four id()'s Oct 26, 2014
-        if id(entry.m_parent.m_child) == id(entry):
-            if id(entry.m_next) != id(entry):
+        if entry.m_parent.m_child is entry:
+            if entry.m_next is not entry:
                 # If there are any other children, pick one of them arbitrarily.
                 entry.m_parent.m_child = entry.m_next
             else:
